@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import unittest
 import doctest
 import datetime
@@ -7,17 +7,18 @@ from dateutil.relativedelta import relativedelta
 from decimal import Decimal
 
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view,\
-    test_depends
+from trytond.tests.test_tryton import ModuleTestCase
+from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT
 from trytond.tests.test_tryton import doctest_setup, doctest_teardown
 from trytond.transaction import Transaction
 
 
-class StockLotTestCase(unittest.TestCase):
+class StockLotTestCase(ModuleTestCase):
     'Test Stock Lot module'
+    module = 'stock_lot'
 
     def setUp(self):
-        trytond.tests.test_tryton.install_module('stock_lot')
+        super(StockLotTestCase, self).setUp()
         self.template = POOL.get('product.template')
         self.product = POOL.get('product.product')
         self.uom = POOL.get('product.uom')
@@ -29,14 +30,6 @@ class StockLotTestCase(unittest.TestCase):
         self.period = POOL.get('stock.period')
         self.cache = POOL.get('stock.period.cache')
 
-    def test0005views(self):
-        'Test views'
-        test_view('stock_lot')
-
-    def test0006depends(self):
-        'Test depends'
-        test_depends()
-
     def test0010products_by_location(self):
         'Test products_by_location'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
@@ -239,7 +232,7 @@ def suite():
     suite = trytond.tests.test_tryton.suite()
     from trytond.modules.company.tests import test_company
     for test in test_company.suite():
-        if test not in suite:
+        if test not in suite and not isinstance(test, doctest.DocTestCase):
             suite.addTest(test)
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             StockLotTestCase))
